@@ -14,7 +14,7 @@ Usage::
     client: OutpostsClient = boto3.client("outposts")
     session_client: OutpostsClient = session.client("outposts")
 """
-from mypy_boto3_outposts.client import OutpostsClient as Client, OutpostsClient
+from mypy_boto3_outposts.client import OutpostsClient, OutpostsClient as Client
 
 
 __all__ = ("Client", "OutpostsClient")
